@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license, see LICENSE.
 """
 A community-driven and oriented Python software project for High Energy Physics.
@@ -7,23 +8,25 @@ from __future__ import absolute_import
 
 from .utils._show_versions import show_versions
 
+from ._version import __version__
 
-__all__ = ['banner',
-           'project_url',
-           'project_url_GitHub',
-           'project_url_PyPI',
-           'show_versions'
-           ]
+
+__all__ = [
+    "banner",
+    "project_url",
+    "project_url_GitHub",
+    "project_url_PyPI" "show_versions",
+    "__version__",
+]
 
 
 # -----------------------------------------------------------------------------
 # Project and package info
 # -----------------------------------------------------------------------------
-__version__ = '1.2.1'
 
-project_url = 'http://scikit-hep.org'
-project_url_GitHub = 'https://github.com/scikit-hep/scikit-hep'
-project_url_PyPI = 'https://pypi.python.org/pypi/scikit-hep'
+project_url = "http://scikit-hep.org"
+project_url_GitHub = "https://github.com/scikit-hep/scikit-hep"
+project_url_PyPI = "https://pypi.python.org/pypi/scikit-hep"
 
 __doc__ = __doc__.format(__version__)
 
