@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license, see LICENSE.
 """
 Vector classes
@@ -39,7 +40,7 @@ class Vector3D(object):
         fromiterable(values)
     """
 
-    def __init__(self, x=0., y=0., z=0.):
+    def __init__(self, x=0.0, y=0.0, z=0.0):
         """Default constructor.
 
         Examples
@@ -58,7 +59,7 @@ class Vector3D(object):
         """Shortcut constuctor for the origin (x=0.,y=0.,z=0.).
         Equivalent to the default constructor Vector3D().
         """
-        return cls(0., 0., 0.)
+        return cls(0.0, 0.0, 0.0)
 
     @classmethod
     def frompoint(cls, x, y, z):
@@ -107,11 +108,15 @@ class Vector3D(object):
         and the length equals 3.
         """
         values = list(values)
-        if not len(values)==3:
-            raise ValueError( 'Input iterable length = {0}! Please check your inputs.'.format(len(values)) )
+        if not len(values) == 3:
+            raise ValueError(
+                "Input iterable length = {0}! Please check your inputs.".format(
+                    len(values)
+                )
+            )
         for i, v in enumerate(values):
-            if not isinstance( v, (int,float) ):
-                raise ValueError( 'Component #{0} is not a number!'.format(i) )
+            if not isinstance(v, (int, float)):
+                raise ValueError("Component #{0} is not a number!".format(i))
         return cls(values[0], values[1], values[2])
 
     @property
@@ -147,7 +152,7 @@ class Vector3D(object):
     @property
     def rho(self):
         """Return the cylindrical coordinate rho."""
-        return sqrt(self.x**2 + self.y**2)
+        return sqrt(self.x ** 2 + self.y ** 2)
 
     @property
     def r(self):
@@ -156,8 +161,8 @@ class Vector3D(object):
 
     def costheta(self):
         """Return the cosine of the spherical coordinate theta."""
-        if self.mag == 0.:
-            return 1.
+        if self.mag == 0.0:
+            return 1.0
         else:
             return self.z / self.mag
 
@@ -192,15 +197,14 @@ class Vector3D(object):
         try:
             self.__values[i] = value
         except IndexError:
-            raise IndexError(
-                'Vector3D is of length {0} only!'.format(len(self)))
+            raise IndexError("Vector3D is of length {0} only!".format(len(self)))
 
     def __getitem__(self, i):
         """Get the ith vector component (commencing at 0, of course)."""
         try:
             return self.__values[i]
         except IndexError:
-            raise IndexError( 'Vector3D is of length {0} only!'.format(len(self)))
+            raise IndexError("Vector3D is of length {0} only!".format(len(self)))
 
     def tolist(self):
         """Return the vector as a list."""
@@ -220,7 +224,7 @@ class Vector3D(object):
         """Square of the magnitude, a.k.a. norm, of the vector."""
         return sum(v ** 2 for v in self.__values)
 
-    def __abs__ ( self ) :
+    def __abs__(self):
         """Get the absolute value for the vector.
 
         Example
@@ -230,7 +234,7 @@ class Vector3D(object):
         """
         return self.mag
 
-    def copy(self) :
+    def copy(self):
         """Get a copy of the vector.
 
         Example
@@ -238,12 +242,12 @@ class Vector3D(object):
         >>> v = ...
         >>> v1 = v.copy()
         """
-        return Vector3D( self[0] , self[1] , self[2] )
+        return Vector3D(self[0], self[1], self[2])
 
     def unit(self):
         """Return the normalized vector, i.e. the unit vector along the direction of itself."""
         mag = self.mag
-        if mag > 0. and mag != 1. :
+        if mag > 0.0 and mag != 1.0:
             return Vector3D.fromiterable([v / mag for v in self.__values])
         else:
             return self
@@ -257,8 +261,12 @@ class Vector3D(object):
         >>> v2  = ...
         >>> v1 += v2
         """
-        if not isinstance ( other ,  Vector3D ) :
-            raise InvalidOperationError("invalid operation '+=' between a 'Vector3D' and a '{0}'".format(other.__class__.__name__))
+        if not isinstance(other, Vector3D):
+            raise InvalidOperationError(
+                "invalid operation '+=' between a 'Vector3D' and a '{0}'".format(
+                    other.__class__.__name__
+                )
+            )
         self.__values[0] += other.__values[0]
         self.__values[1] += other.__values[1]
         self.__values[2] += other.__values[2]
@@ -273,8 +281,12 @@ class Vector3D(object):
         >>> v2  = ...
         >>> v1 -= v2
         """
-        if not isinstance ( other ,  Vector3D ) :
-            raise InvalidOperationError("invalid operation '-=' between a 'Vector3D' and a '{0}'".format(other.__class__.__name__))
+        if not isinstance(other, Vector3D):
+            raise InvalidOperationError(
+                "invalid operation '-=' between a 'Vector3D' and a '{0}'".format(
+                    other.__class__.__name__
+                )
+            )
         self.__values[0] -= other.__values[0]
         self.__values[1] -= other.__values[1]
         self.__values[2] -= other.__values[2]
@@ -282,16 +294,18 @@ class Vector3D(object):
 
     def __add__(self, other):
         """Addition with another vector, i.e. self+other."""
-        if not isinstance ( other ,  Vector3D ) : return NotImplemented
+        if not isinstance(other, Vector3D):
+            return NotImplemented
         v = self.copy()
-        v+= other
+        v += other
         return v
 
     def __sub__(self, other):
         """Subtraction with another vector, i.e. self-other."""
-        if not isinstance ( other ,  Vector3D ) : return NotImplemented
+        if not isinstance(other, Vector3D):
+            return NotImplemented
         v = self.copy()
-        v-= other
+        v -= other
         return v
 
     def __imul__(self, other):
@@ -302,10 +316,14 @@ class Vector3D(object):
         >>> v = ...
         >>> v *= 2
         """
-        if isinstance ( other , ( int , float ) ) :
-            return Vector3D.fromiterable ( [v * other for v in self.__values ] )
+        if isinstance(other, (int, float)):
+            return Vector3D.fromiterable([v * other for v in self.__values])
         else:
-            raise InvalidOperationError("invalid operation '*=' between a 'Vector3D' and a '{0}'".format(other.__class__.__name__))
+            raise InvalidOperationError(
+                "invalid operation '*=' between a 'Vector3D' and a '{0}'".format(
+                    other.__class__.__name__
+                )
+            )
 
     def __itruediv__(self, number):
         """Scaling of the vector by a number.
@@ -315,10 +333,15 @@ class Vector3D(object):
         >>> v  = ...
         >>> v /= 2
         """
-        if not isinstance ( number , ( int , float ) ) :
-            raise InvalidOperationError("invalid operation '/=' between a 'Vector3D' and a '{0}'".format(number.__class__.__name__))
-        elif 0 == number : raise ZeroDivisionError
-        self *= ( 1.0/number )
+        if not isinstance(number, (int, float)):
+            raise InvalidOperationError(
+                "invalid operation '/=' between a 'Vector3D' and a '{0}'".format(
+                    number.__class__.__name__
+                )
+            )
+        elif 0 == number:
+            raise ZeroDivisionError
+        self *= 1.0 / number
         return self
 
     __idiv__ = __itruediv__
@@ -332,7 +355,7 @@ class Vector3D(object):
         >>> v2 = v1 * 2
         >>> number = v1 * v3
         """
-        if isinstance ( other ,  Vector3D ) :
+        if isinstance(other, Vector3D):
             return self.dot(other)
         v = self.copy()
         v *= other
@@ -350,7 +373,7 @@ class Vector3D(object):
 
     __div__ = __truediv__
 
-    def __eq__  ( self , other ) :
+    def __eq__(self, other):
         """Equality to another vector, or, equality to zero.
 
         Example
@@ -363,14 +386,18 @@ class Vector3D(object):
         from skhep.math.numeric import isequal
 
         ## comparsion with scalar zero, very useful  in practice
-        if isinstance ( other , ( float , int , long ) ) and isequal ( other , 0 ) :
-            return isequal ( self[0] , 0 ) and isequal ( self[1] , 0 ) and isequal ( self[2] , 0 )
-        elif not isinstance ( other , Vector3D) :
+        if isinstance(other, (float, int, long)) and isequal(other, 0):
+            return isequal(self[0], 0) and isequal(self[1], 0) and isequal(self[2], 0)
+        elif not isinstance(other, Vector3D):
             return NotImplemented
         ##
-        return isequal ( self[0] , other[0] ) and isequal ( self[1] , other[1] ) and isequal ( self[2] , other[2] )
+        return (
+            isequal(self[0], other[0])
+            and isequal(self[1], other[1])
+            and isequal(self[2], other[2])
+        )
 
-    def __ne__  (self, other) :
+    def __ne__(self, other):
         """Non-equality to another vector.
 
         Example
@@ -379,9 +406,9 @@ class Vector3D(object):
         >>> v2 = ...
         >>> print v1 != v2
         """
-        return not ( self == other )
+        return not (self == other)
 
-    def __nonzero__ ( self ) :
+    def __nonzero__(self):
         """Non-zero vector?
 
         Example
@@ -401,12 +428,13 @@ class Vector3D(object):
         """Dot product with another vector."""
         return sum(v1 * v2 for v1, v2 in zip(self.__values, other.__values))
 
-    def cross(self, other ):
+    def cross(self, other):
         """Cross product with another vector."""
-        return Vector3D( self[1] * other[2] - self[2] * other[1],
-                         self[2] * other[0] - self[0] * other[2],
-                         self[0] * other[1] - self[1] * other[0]
-                        )
+        return Vector3D(
+            self[1] * other[2] - self[2] * other[1],
+            self[2] * other[0] - self[0] * other[2],
+            self[0] * other[1] - self[1] * other[0],
+        )
 
     def rotate(self, angle, *args):
         """Rotate vector by a given angle (in radians) around a given axis."""
@@ -417,24 +445,37 @@ class Vector3D(object):
         elif len(args) == 3:
             ux, uy, uz = args
         else:
-            raise TypeError('Input object not a Vector3D nor an iterable with 3 elements.')
+            raise TypeError(
+                "Input object not a Vector3D nor an iterable with 3 elements."
+            )
 
         for i, u in enumerate((ux, uy, uz)):
-            if not isinstance( u, (int,float) ):
-                raise ValueError( 'Component #{0} is not a number!'.format(i) )
+            if not isinstance(u, (int, float)):
+                raise ValueError("Component #{0} is not a number!".format(i))
 
-        norm = sqrt(ux**2 + uy**2 + uz**2)
+        norm = sqrt(ux ** 2 + uy ** 2 + uz ** 2)
         if norm != 1.0:
-            ux = ux / norm; uy = uy / norm; uz = uz / norm;
+            ux = ux / norm
+            uy = uy / norm
+            uz = uz / norm
         c, s = cos(angle), sin(angle)
-        c1 = 1. - c
+        c1 = 1.0 - c
 
-        xp = (c + ux**2 * c1) * self.x + (ux * uy * c1 - uz * s) * self.y \
+        xp = (
+            (c + ux ** 2 * c1) * self.x
+            + (ux * uy * c1 - uz * s) * self.y
             + (ux * uz * c1 + uy * s) * self.z
-        yp = (ux * uy * c1 + uz * s) * self.x + (c + uy**2 * c1) * self.y \
+        )
+        yp = (
+            (ux * uy * c1 + uz * s) * self.x
+            + (c + uy ** 2 * c1) * self.y
             + (uy * uz * c1 - ux * s) * self.z
-        zp = (ux * uz * c1 - uy * s) * self.x + (uy * uz * c1 + ux * s) * self.y \
-            + (c + uz**2 * c1) * self.z
+        )
+        zp = (
+            (ux * uz * c1 - uy * s) * self.x
+            + (uy * uz * c1 + ux * s) * self.y
+            + (c + uz ** 2 * c1) * self.z
+        )
 
         return Vector3D(xp, yp, zp)
 
@@ -450,17 +491,17 @@ class Vector3D(object):
         """Rotate vector by a given angle (in radians) around the z axis."""
         return self.rotate(angle, 0, 0, 1)
 
-    def cosdelta ( self , other ) :
-        """Get cos(angle) with respect to another vector
-        """
+    def cosdelta(self, other):
+        """Get cos(angle) with respect to another vector"""
         m1 = self.mag2
-        if 0 >= m1 : return 1.0
+        if 0 >= m1:
+            return 1.0
         m2 = other.mag2
-        if 0 >= m2 : return 1.0
-
-        r = self.dot( other ) / sqrt ( m1 * m2 )
-        return max ( -1.0 , min ( 1.0 , r ) )
+        if 0 >= m2:
+            return 1.0
 
+        r = self.dot(other) / sqrt(m1 * m2)
+        return max(-1.0, min(1.0, r))
 
     def angle(self, other, deg=False):
         """
@@ -471,7 +512,7 @@ class Vector3D(object):
         deg : float, optional
             Return the angle in degrees (default is radians).
         """
-        cd = self.cosdelta ( other )
+        cd = self.cosdelta(other)
         return acos(cd) if not deg else degrees(acos(cd))
 
     def isparallel(self, other):
@@ -479,32 +520,37 @@ class Vector3D(object):
         Two vectors are parallel if they have the same direction but not necessarily the same magnitude.
         """
         from skhep.math.numeric import isequal
-        return isequal ( self.cosdelta(other)  , 1 )
+
+        return isequal(self.cosdelta(other), 1)
 
     def isantiparallel(self, other):
         """Check if another vector is antiparallel.
         Two vectors are antiparallel if they have opposite direction but not necessarily the same magnitude.
         """
         from skhep.math.numeric import isequal
-        return isequal ( self.cosdelta(other) , -1 )
 
-    def iscollinear ( self , other ) :
+        return isequal(self.cosdelta(other), -1)
+
+    def iscollinear(self, other):
         """Check if another vector is collinear
         Two vectors are collinear if they have parallel or antiparallel
         """
         from skhep.math.numeric import isequal
-        return isequal ( abs ( self.cosdelta ( other ) ) , 1 )
 
-    def isopposite ( self , other):
+        return isequal(abs(self.cosdelta(other)), 1)
+
+    def isopposite(self, other):
         """Two vectors are opposite if they have the same magnitude but opposite direction."""
         from skhep.math.numeric import isequal
+
         added = self + other
         return added == 0
 
     def isperpendicular(self, other):
         """Check if another vector is perpendicular."""
         from skhep.math.numeric import isequal
-        return isequal ( self.dot ( other ) , 0 , scale = max( self.mag2 , other.mag2 ) )
+
+        return isequal(self.dot(other), 0, scale=max(self.mag2, other.mag2))
 
     def __repr__(self):
         """Class representation."""
@@ -514,9 +560,10 @@ class Vector3D(object):
         """Simple class representation."""
         return str(tuple(self.__values))
 
-#-----------------------------------------------------------------------------
+
+# -----------------------------------------------------------------------------
 # Lorentz vector class
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 class LorentzVector(object):
     """
     Class representing a Lorentz vector,
@@ -528,7 +575,8 @@ class LorentzVector(object):
         from4vector(avector)
         from3vector(vector3d, t)
     """
-    def __init__(self, x=0., y=0., z=0., t=0.):
+
+    def __init__(self, x=0.0, y=0.0, z=0.0, t=0.0):
         """Default constructor.
 
         Example
@@ -539,7 +587,6 @@ class LorentzVector(object):
         self.__vector3d = Vector3D(x, y, z)
         self.__t = t
 
-
     @classmethod
     def from4vector(cls, other):
         """Copy constructor."""
@@ -557,11 +604,15 @@ class LorentzVector(object):
         and the length equals 4.
         """
         values = list(values)
-        if not len(values)==4:
-            raise ValueError( 'Input iterable length = {0}! Please check your inputs.'.format(len(values)) )
+        if not len(values) == 4:
+            raise ValueError(
+                "Input iterable length = {0}! Please check your inputs.".format(
+                    len(values)
+                )
+            )
         for i, v in enumerate(values):
-            if not isinstance( v, (int,float) ):
-                raise ValueError( 'Component #{0} is not a number!'.format(i) )
+            if not isinstance(v, (int, float)):
+                raise ValueError("Component #{0} is not a number!".format(i))
         return cls(values[0], values[1], values[2], values[3])
 
     @property
@@ -682,25 +733,27 @@ class LorentzVector(object):
 
     def setpxpypzm(self, px, py, pz, m):
         """Set the px,py,pz components and the mass."""
-        self.__vector3d.x = px; self.__vector3d.y = py; self.__vector3d.z = pz
-        if m > 0.:
-            self.__t = sqrt(px**2 + py**2 + pz**2 + m**2)
+        self.__vector3d.x = px
+        self.__vector3d.y = py
+        self.__vector3d.z = pz
+        if m > 0.0:
+            self.__t = sqrt(px ** 2 + py ** 2 + pz ** 2 + m ** 2)
         else:
-            self.__t = sqrt(px**2 + py**2 + pz**2 - m**2)
+            self.__t = sqrt(px ** 2 + py ** 2 + pz ** 2 - m ** 2)
 
     def setpxpypze(self, px, py, pz, e):
         """Set the px,py,pz components and the energy."""
-        self.set(px,py,pz,e)
+        self.set(px, py, pz, e)
 
     def setptetaphim(self, pt, eta, phi, m):
         """ Set the transverse momentum, the pseudorapidity, the angle phi and the mass."""
-        px, py, pz = pt*cos(phi), pt*sin(phi), pt*sinh(eta)
-        self.setpxpypzm(px,py,pz,m)
+        px, py, pz = pt * cos(phi), pt * sin(phi), pt * sinh(eta)
+        self.setpxpypzm(px, py, pz, m)
 
     def setptetaphie(self, pt, eta, phi, e):
         """ Set the transverse momentum, the pseudorapidity, the angle phi and the energy."""
-        px, py, pz = pt*cos(phi), pt*sin(phi), pt*sinh(eta)
-        self.setpxpypze(px,py,pz,e)
+        px, py, pz = pt * cos(phi), pt * sin(phi), pt * sinh(eta)
+        self.setpxpypze(px, py, pz, e)
 
     def tolist(self):
         """Return the LorentzVector as a list."""
@@ -709,18 +762,19 @@ class LorentzVector(object):
     def __setitem__(self, i, value):
         """Update/set the ith vector component (commencing at 0, of course)."""
         try:
-            if i == 3: self.__t = value
-            else: self.__vector3d[i] = value
+            if i == 3:
+                self.__t = value
+            else:
+                self.__vector3d[i] = value
         except IndexError:
-            raise IndexError(
-                'LorentzVector is of length {0} only!'.format(len(self)))
+            raise IndexError("LorentzVector is of length {0} only!".format(len(self)))
 
     def __getitem__(self, i):
         """Get the ith vector component (commencing at 0, of course)."""
         try:
             return self.tolist()[i]
         except IndexError:
-            raise IndexError( 'LorentzVector is of length {0} only!'.format(len(self)))
+            raise IndexError("LorentzVector is of length {0} only!".format(len(self)))
 
     def __len__(self):
         """Length of the LorentzVector, i.e. the number of elements = 4."""
@@ -739,7 +793,7 @@ class LorentzVector(object):
     @property
     def et(self):
         """Return the transverse energy."""
-        return self.e * ( self.pt / self.p )
+        return self.e * (self.pt / self.p)
 
     @property
     def m(self):
@@ -775,12 +829,12 @@ class LorentzVector(object):
     def transversemass(self):
         """Return the transverse mass."""
         mt2 = self.transversemass2
-        return sqrt(mt2) if mt2 >= 0. else -sqrt(-mt2)
+        return sqrt(mt2) if mt2 >= 0.0 else -sqrt(-mt2)
 
     @property
     def transversemass2(self):
         """Return the square of the transverse mass."""
-        return self.e**2 - self.pz**2
+        return self.e ** 2 - self.pz ** 2
 
     @property
     def beta(self):
@@ -791,17 +845,17 @@ class LorentzVector(object):
     def gamma(self):
         """Return :math:`\\gamma = 1/\\sqrt{1-\\beta^2}`."""
         if self.beta < 1:
-            return 1. / sqrt(1. - self.beta**2)
+            return 1.0 / sqrt(1.0 - self.beta ** 2)
         else:
-            return 10E10
+            return 10e10
 
     @property
     def eta(self):
         """Return the pseudorapidity."""
-        if abs(self.costheta()) < 1.:
-            return -0.5 * log( (1. - self.costheta())/(1. + self.costheta()) )
+        if abs(self.costheta()) < 1.0:
+            return -0.5 * log((1.0 - self.costheta()) / (1.0 + self.costheta()))
         else:
-            return 10E10 if self.z > 0 else -10E10
+            return 10e10 if self.z > 0 else -10e10
 
     @property
     def boostvector(self):
@@ -816,30 +870,30 @@ class LorentzVector(object):
     @property
     def rapidity(self):
         """Return the rapidity."""
-        return 0.5 * log( (self.e + self.pz)/(self.e - self.pz) )
+        return 0.5 * log((self.e + self.pz) / (self.e - self.pz))
 
     @property
     def mag(self):
         """Magnitude, a.k.a. norm, of the Lorentz vector."""
         mag2 = self.mag2
-        return sqrt(mag2) if mag2 >= 0. else -sqrt(-mag2)
+        return sqrt(mag2) if mag2 >= 0.0 else -sqrt(-mag2)
 
     @property
     def mag2(self):
         """Square of the magnitude, a.k.a. norm, of the Lorentz vector."""
-        return self.t**2 - self.__vector3d.mag2
+        return self.t ** 2 - self.__vector3d.mag2
 
     @property
     def perp2(self):
         """Square of the transverse component, in the (x,y) plane, of the spatial components."""
-        return self.x**2 + self.y**2
+        return self.x ** 2 + self.y ** 2
 
     @property
     def perp(self):
         """Transverse component of the spatial components."""
         return sqrt(self.perp2)
 
-    def copy(self) :
+    def copy(self):
         """Get a copy of the LorentzVector.
 
         Example
@@ -847,7 +901,7 @@ class LorentzVector(object):
         >>> v = ...
         >>> v1 = v.copy()
         """
-        return LorentzVector( self[0] , self[1] , self[2] , self[3] )
+        return LorentzVector(self[0], self[1], self[2], self[3])
 
     def __iadd__(self, other):
         """(self)Addition with another LorentzVector, i.e. self+other.
@@ -858,8 +912,12 @@ class LorentzVector(object):
         >>> v2  = ...
         >>> v1 += v2
         """
-        if not isinstance ( other ,  LorentzVector ) :
-            raise InvalidOperationError("invalid operation '+=' between a 'LorentzVector' and a '{0}'".format(other.__class__.__name__))
+        if not isinstance(other, LorentzVector):
+            raise InvalidOperationError(
+                "invalid operation '+=' between a 'LorentzVector' and a '{0}'".format(
+                    other.__class__.__name__
+                )
+            )
         self.__vector3d += other.__vector3d
         self.__t += other.__t
         return self
@@ -873,8 +931,12 @@ class LorentzVector(object):
         >>> v2  = ...
         >>> v1 -= v2
         """
-        if not isinstance ( other ,  LorentzVector ) :
-            raise InvalidOperationError("invalid operation '-=' between a 'LorentzVector' and a '{0}'".format(other.__class__.__name__))
+        if not isinstance(other, LorentzVector):
+            raise InvalidOperationError(
+                "invalid operation '-=' between a 'LorentzVector' and a '{0}'".format(
+                    other.__class__.__name__
+                )
+            )
         self.__vector3d -= other.__vector3d
         self.__t -= other.__t
         return self
@@ -882,16 +944,15 @@ class LorentzVector(object):
     def __add__(self, other):
         """Addition with another LorentzVector, i.e. self+other."""
         v = self.copy()
-        v+= other
+        v += other
         return v
 
     def __sub__(self, other):
         """Subtraction with another LorentzVector, i.e. self-other."""
         v = self.copy()
-        v-= other
+        v -= other
         return v
 
-
     def __imul__(self, other):
         """Scaling of the Lorentz vector with a number.
 
@@ -900,10 +961,14 @@ class LorentzVector(object):
         >>> v = ...
         >>> v *= 2
         """
-        if isinstance ( other , ( int , float ) ) :
-            return LorentzVector.fromiterable ( [v * other for v in self.tolist() ] )
+        if isinstance(other, (int, float)):
+            return LorentzVector.fromiterable([v * other for v in self.tolist()])
         else:
-            raise InvalidOperationError("invalid operation '*=' between a 'LorentzVector' and a '{0}'".format(other.__class__.__name__))
+            raise InvalidOperationError(
+                "invalid operation '*=' between a 'LorentzVector' and a '{0}'".format(
+                    other.__class__.__name__
+                )
+            )
 
     def __itruediv__(self, number):
         """Scaling of the Lorentz vector with a number.
@@ -913,10 +978,15 @@ class LorentzVector(object):
         >>> v  = ...
         >>> v /= 2
         """
-        if not isinstance ( number , ( int , float ) ) :
-            raise InvalidOperationError("invalid operation '/=' between a 'LorentzVector' and a '{0}'".format(number.__class__.__name__))
-        elif 0 == number : raise ZeroDivisionError
-        self *= ( 1.0/number )
+        if not isinstance(number, (int, float)):
+            raise InvalidOperationError(
+                "invalid operation '/=' between a 'LorentzVector' and a '{0}'".format(
+                    number.__class__.__name__
+                )
+            )
+        elif 0 == number:
+            raise ZeroDivisionError
+        self *= 1.0 / number
         return self
 
     __idiv__ = __itruediv__
@@ -930,7 +1000,7 @@ class LorentzVector(object):
         >>> v2 = v1 * 2
         >>> number = v1 * v3
         """
-        if isinstance ( other , LorentzVector ):
+        if isinstance(other, LorentzVector):
             return self.dot(other)
         v = self.copy()
         v *= other
@@ -948,7 +1018,7 @@ class LorentzVector(object):
 
     __div__ = __truediv__
 
-    def __eq__  ( self , other ) :
+    def __eq__(self, other):
         """Equality to another LorentzVector, or, equality to zero.
 
         Example
@@ -961,16 +1031,24 @@ class LorentzVector(object):
         from skhep.math.numeric import isequal
 
         ## comparsion with scalar zero, very useful  in practice
-        if isinstance ( other , ( float , int , long ) ) and isequal ( other , 0 ) :
-            return isequal ( self[0] , 0 ) and isequal ( self[1] , 0 ) and isequal ( self[2] , 0 ) \
-             and isequal ( self[3] , 0 )
-        elif not isinstance ( other , LorentzVector ) :
+        if isinstance(other, (float, int, long)) and isequal(other, 0):
+            return (
+                isequal(self[0], 0)
+                and isequal(self[1], 0)
+                and isequal(self[2], 0)
+                and isequal(self[3], 0)
+            )
+        elif not isinstance(other, LorentzVector):
             return NotImplemented
         ##
-        return isequal ( self[0] , other[0] ) and isequal ( self[1] , other[1] ) and isequal ( self[2] , other[2] ) \
-         and isequal ( self[3] , other[3] )
+        return (
+            isequal(self[0], other[0])
+            and isequal(self[1], other[1])
+            and isequal(self[2], other[2])
+            and isequal(self[3], other[3])
+        )
 
-    def __ne__  (self, other) :
+    def __ne__(self, other):
         """Non-equality to another Lorentz vector.
 
         Example
@@ -979,7 +1057,7 @@ class LorentzVector(object):
         >>> v2 = ...
         >>> print v1 != v2
         """
-        return not ( self == other )
+        return not (self == other)
 
     def __iter__(self):
         """Iterator implementation for the Lorentz vector components."""
@@ -994,24 +1072,26 @@ class LorentzVector(object):
         elif len(args) == 3:
             bx, by, bz = args
         else:
-            raise TypeError('Input object not a Vector3D nor an iterable with 3 elements.')
+            raise TypeError(
+                "Input object not a Vector3D nor an iterable with 3 elements."
+            )
 
         for i, b in enumerate((bx, by, bz)):
-            if not isinstance( b, (int,float) ):
-                raise ValueError( 'Component #{0} is not a number!'.format(i) )
+            if not isinstance(b, (int, float)):
+                raise ValueError("Component #{0} is not a number!".format(i))
 
-        b2 = bx**2 + by**2 + bz**2
-        gamma = 1. / sqrt( 1. - b2 )
+        b2 = bx ** 2 + by ** 2 + bz ** 2
+        gamma = 1.0 / sqrt(1.0 - b2)
         bp = bx * self.x + by * self.y + bz * self.z
-        if b2 > 0.:
-            gamma2 = ( gamma - 1. ) / b2
+        if b2 > 0.0:
+            gamma2 = (gamma - 1.0) / b2
         else:
-            gamma2 = 0.
+            gamma2 = 0.0
 
         xp = self.x + gamma2 * bp * bx - gamma * bx * self.t
         yp = self.y + gamma2 * bp * by - gamma * by * self.t
         zp = self.z + gamma2 * bp * bz - gamma * bz * self.t
-        tp = gamma * ( self.t - bp )
+        tp = gamma * (self.t - bp)
 
         return LorentzVector(xp, yp, zp, tp)
 
@@ -1046,31 +1126,34 @@ class LorentzVector(object):
         """Return the phi angle difference, :math:`\\Delta \\phi`, with another Lorentz vector."""
         dphi = self.phi() - other.phi()
         while dphi > pi:
-            dphi -= 2*pi
+            dphi -= 2 * pi
         while dphi < -pi:
-            dphi += 2*pi
+            dphi += 2 * pi
         return dphi
 
     def deltar(self, other):
         """Return :math:`\\Delta R` the distance in (eta,phi) space with another Lorentz vector, defined as:
         :math:`\\Delta R = \\sqrt{(\\Delta \\eta)^2 + (\\Delta \\phi)^2}`
         """
-        return sqrt( self.deltaeta(other)**2 + self.deltaphi(other)**2 )
+        return sqrt(self.deltaeta(other) ** 2 + self.deltaphi(other) ** 2)
 
     def isspacelike(self):
         """Check if Lorentz Vector is space-like."""
         from skhep.math.numeric import isequal
-        return self.mag2 < 0. and not isequal(self.mag2, 0.)
+
+        return self.mag2 < 0.0 and not isequal(self.mag2, 0.0)
 
     def istimelike(self):
         """Check if Lorentz Vector is time-like."""
         from skhep.math.numeric import isequal
-        return self.mag2 > 0. and not isequal(self.mag2, 0.)
+
+        return self.mag2 > 0.0 and not isequal(self.mag2, 0.0)
 
     def islightlike(self):
         """Check if Lorentz Vector is light-like."""
         from skhep.math.numeric import isequal
-        return isequal(self.mag2, 0.)
+
+        return isequal(self.mag2, 0.0)
 
     def __repr__(self):
         """Class representation."""
